@@ -3,8 +3,8 @@
 
 import warnings
 
-from .base_utils import (AioQueue, DefaultDict, Dict, DictUnwrapper,
-                         DictWrapper, JSONEncoder, Queue, Singleton, Storage,
+from .base_utils import (DefaultDict, Dict, DictUnwrapper,
+                         DictWrapper, JSONEncoder, Singleton, Storage,
                          awaitable, ceil, check_connect, floor, get_ip, int2ip,
                          int2str, ip2int, multi_apply, pprint, str2int,
                          to_bytes, to_str, tqdm, yaml)
@@ -36,8 +36,8 @@ __all__ = [
     'timeit', 'retry', 'aioretry', 'smart_decorator', 'synchronize', 'cached_property', 'multi_apply',
     'get_ip', 'check_connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool', 'parse_uri',
     'des_encrypt', 'des_decrypt', 'aes_encrypt', 'aes_decrypt', 'gen_rsa_key', 'rsa_encrypt', 'rsa_decrypt',
-    'Fire', 'Ip2Region', 'Singleton', 'JSONEncoder', 'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
-    'Email', 'AioEmail', 'Queue', 'AioQueue', 'Config', 'Logger', 'WatchedFileHandler', 'Storage',
+    'Fire', 'Singleton', 'JSONEncoder', 'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
+    'Email', 'AioEmail', 'Config', 'Logger', 'WatchedFileHandler', 'Storage', 'XdbSearcher',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient', 'Mysql', 'AioMysql', 'Pika', 'AioPika',
     'Request', 'Response', 'Chrome'
 ]
