@@ -7,7 +7,6 @@ Created at:    2021-10-30 17:03:31
 Last modified: 2021-11-01 15:26:05
 '''
 
-import asyncio
 import collections
 import datetime
 import decimal
@@ -15,7 +14,6 @@ import inspect
 import json
 import math
 import os
-import queue
 import socket
 import sys
 import threading
@@ -28,13 +26,45 @@ from struct import pack, unpack
 
 import requests
 import yaml
-from orderedset import OrderedSet
 from pymongo.cursor import Cursor
 from rich.console import Console
 from rich.table import Table
 from tqdm import tqdm
 
 
+'''
+class Queue(queue.Queue):
+
+    def _init(self, maxsize):
+        self.queue = OrderedSet()
+
+    def _put(self, item):
+        self.queue.add(item)
+
+    def _get(self):
+        return self.queue.pop(last=False)
+
+    def __contains__(self, item):
+        with self.mutex:
+            return item in self.queue
+
+
+class AioQueue(asyncio.Queue):
+
+    def _init(self, maxsize):
+        self._queue = OrderedSet()
+
+    def _put(self, item):
+        self._queue.add(item)
+
+    def _get(self):
+        return self._queue.pop(last=False)
+
+    def __contains__(self, item):
+        return item in self.queue
+'''
+
+
 def _include_yaml(loader, node):
     root = Path(loader.name).parent
     if isinstance(node, yaml.SequenceNode):
@@ -79,37 +109,6 @@ class tqdm(tqdm):
             super().update(incr)
 
 
-class Queue(queue.Queue):
-
-    def _init(self, maxsize):
-        self.queue = OrderedSet()
-
-    def _put(self, item):
-        self.queue.add(item)
-
-    def _get(self):
-        return self.queue.pop(last=False)
-
-    def __contains__(self, item):
-        with self.mutex:
-            return item in self.queue
-
-
-class AioQueue(asyncio.Queue):
-
-    def _init(self, maxsize):
-        self._queue = OrderedSet()
-
-    def _put(self, item):
-        self._queue.add(item)
-
-    def _get(self):
-        return self._queue.pop(last=False)
-
-    def __contains__(self, item):
-        return item in self.queue
-
-
 class JSONEncoder(json.encoder.JSONEncoder):
     '''针对某些不能序列化的类型如datetime，使用json.dumps(data, cls=JSONEncoder)
     '''
