@@ -118,26 +118,27 @@ class Pycurl(BaseRequest):
         elif isinstance(data, (dict, list, tuple)):
             data = urlencode(data)
 
-        if kwargs['method'] in ("POST", "PATCH", "PUT"):
+        if kwargs['method'] in ("POST", "DELETE"):
+            curl.setopt(pycurl.POSTFIELDS, data)
+            curl.setopt(pycurl.POSTFIELDSIZE, len(data))
+        elif kwargs['method'] in ("PATCH", "PUT"):
             request_buffer = io.BytesIO(to_bytes(data))
             curl.setopt(pycurl.READFUNCTION, request_buffer.read)
             curl.setopt(pycurl.IOCTLFUNCTION, lambda cmd: cmd == curl.IOCMD_RESTARTREAD and request_buffer.seek(0))
-            if kwargs['method'] == 'POST':
-                curl.setopt(pycurl.POSTFIELDSIZE, len(data))
-            else:
-                curl.setopt(pycurl.UPLOAD, True)
-                curl.setopt(pycurl.INFILESIZE, len(data))
-            '''
-            fields = []
-            if isinstance(data, collections.Iterable):
-                for k, v in data:
-                    fields.append((k, (pycurl.FORM_CONTENTS, to_str(v))))
-            if isinstance(files, collections.Iterable):
-                for k, v in files:
-                    fields.append((k, (pycurl.FORM_FILE, to_str(v[1].name))))
-            curl.setopt(pycurl.HTTPPOST, fields)
-            curl.setopt(pycurl.POSTFIELDS, data)
-            '''
+            curl.setopt(pycurl.UPLOAD, True)
+            curl.setopt(pycurl.INFILESIZE, len(data))
+
+        '''
+        fields = []
+        if isinstance(data, collections.Iterable):
+            for k, v in data:
+                fields.append((k, (pycurl.FORM_CONTENTS, to_str(v))))
+        if isinstance(files, collections.Iterable):
+            for k, v in files:
+                fields.append((k, (pycurl.FORM_FILE, to_str(v[1].name))))
+        curl.setopt(pycurl.HTTPPOST, fields)
+        curl.setopt(pycurl.POSTFIELDS, data)
+        '''
 
         for key in ['Expect', 'Pragma']:
             headers.setdefault(key, '')
