@@ -12,7 +12,7 @@ import re
 from urllib.parse import parse_qs, quote_plus, unquote_plus
 
 import aiomysql
-import aredis
+import aioredis
 import pymongo
 import pymysql
 import redis
@@ -143,9 +143,9 @@ class MongoClient(pymongo.MongoClient):
             password = os.environ.get('MONGO_PWD', None)
             uri = f"mongodb://{quote_plus(user)}:{quote_plus(password)}@{host}:{port}" if user and password else f"mongodb://{host}:{port}"
 
-        if 'uri' in kwargs:
-            kwargs.pop('uri')
+        kwargs.pop('uri', None)
         kwargs.setdefault('document_class', Dict)
+        self.__db = parse_uri(uri).get('db')
         super(MongoClient, self).__init__(uri, **kwargs)
 
     def __getitem__(self, name):
@@ -157,7 +157,7 @@ class MongoClient(pymongo.MongoClient):
 
 class Mongo(Database):
 
-    def __init__(self, db='test', **kwargs):
+    def __init__(self, db, **kwargs):
         client = MongoClient(**kwargs)
         super(Mongo, self).__init__(client, db)
 
@@ -284,8 +284,7 @@ class Redis(redis.StrictRedis):
             db = int(os.environ.get("REDIS_DB", 0))
             uri = f"redis://:{password}@{host}:{port}/{db}" if password else f"redis://{host}:{port}/{db}"
 
-        if 'uri' in kwargs:
-            kwargs.pop('uri')
+        kwargs.pop('uri', None)
         kwargs.setdefault('decode_responses', True)
         pool = redis.ConnectionPool.from_url(uri, **kwargs)
         super().__init__(connection_pool=pool)
@@ -299,7 +298,7 @@ class Redis(redis.StrictRedis):
                 self.delete(*keys)
 
 
-class AioRedis(aredis.StrictRedis):
+class AioRedis(aioredis.StrictRedis):
 
     def __init__(self, **kwargs):
         if any([key in kwargs for key in ['host', 'port', 'password']]):
@@ -319,10 +318,9 @@ class AioRedis(aredis.StrictRedis):
             db = int(os.environ.get("REDIS_DB", 0))
             uri = f"redis://:{password}@{host}:{port}/{db}" if password else f"redis://{host}:{port}/{db}"
 
-        if 'uri' in kwargs:
-            kwargs.pop('uri')
+        kwargs.pop('uri', None)
         kwargs.setdefault('decode_responses', True)
-        pool = aredis.ConnectionPool.from_url(uri, **kwargs)
+        pool = aioredis.ConnectionPool.from_url(uri, **kwargs)
         super().__init__(connection_pool=pool)
 
     async def clear(self, pattern='*'):
@@ -456,6 +454,15 @@ class AioMysql(Mysql):
         finally:
             await cursor.close()
 
+    async def query_td(self, sql, *args):
+        cursor = await self.cursor()
+        try:
+            await self._execute(cursor, sql, args)
+            rows = await cursor.fetchall()
+            return {'th': [col[0] for col in cursor._description], 'td': rows}
+        finally:
+            await cursor.close()
+
     async def get(self, sql, *args):
         cursor = await self.cursor()
         try:
